<!DOCTYPE TS><TS>
<context>
    <name>AddRecording</name>
    <message>
        <source>Schedule a:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Macro Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Switch Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CatchListView</name>
    <message>
        <source>Edit Cue Markers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeckMon</name>
    <message>
        <source>MON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ABORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFFLINE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IDLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>READY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WAITING</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RECORDING</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAYING</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[multiple events]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[unknown cut]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[no description]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCartEvent</name>
    <message>
        <source>Edit Cart Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That cart doesn&apos;t exist!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditDownload</name>
    <message>
        <source>Edit Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Library Metadata</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPlayout</name>
    <message>
        <source>Edit Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditRecording</name>
    <message>
        <source>Edit Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Hard Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use GPI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPI Matrix:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPI Line:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Multiple Recordings within this Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record End Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window End Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max Record Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Date Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Date Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must assign a record cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Parameter Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The start GPI window cannot end before it begins!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recording cannot end before it begins!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The end GPI window cannot end before it begins!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The start GPI matrix doesn&apos;t exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The start GPI line doesn&apos;t exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The end GPI matrix doesn&apos;t exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The end GPI line doesn&apos;t exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditSwitchEvent</name>
    <message>
        <source>Edit Switcher Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Matrix:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Input:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Output:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--OFF--</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditUpload</name>
    <message>
        <source>Edit Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RSS Feed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on this host!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on host </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Library Metadata</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload/Download Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>rdcatch : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Only Active Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Only Today&apos;s Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show DayOfWeek:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOCATION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>END</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESTINATION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ONE SHOT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRIM THRESHOLD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STARTDATE OFFSET</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ENDDATE OFFSET</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FORMAT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CHANNELS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SAMPLE RATE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BIT RATE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STATION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DECK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CUT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EXIT CODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STATE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot edit an active event!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Control connection timed out to host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Su</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Th</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gpi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Event Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Types</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
